# cszp Easy soccer execution program
[![Build Status](https://travis-ci.org/kumitatepazuru/cszp.svg?branch=master)](https://travis-ci.org/kumitatepazuru/cszp)

![Logo](https://raw.githubusercontent.com/kumitatepazuru/cszp/master/logo.png)

[日本語ページはこちら](https://github.com/kumitatepazuru/cszp/blob/master/README_jp.md)


## Download
### Note This program is premised on running on linux (Debian system). So it may not run on other OS.
Operation check OS
- ubuntu 16.04LTS
- ubuntu server 16.04LTS
- debian 10.1
- zorinos 15.2
- ubuntu 18.04LTS
- ubuntu 20.04LTS

## How to install

```
pip3 install cszp
```

## Bugs, features you want to add
#### [Here!](https://github.com/kumitatepazuru/cszp/issues)
